@@ -1,8 +1,13 @@
 # -*- coding: utf-8 -*-
 from .classification_dataset import ClassificationDataset
 from .tagging_dataset import TaggingDataset
+from .similarity_dataset import SimilarityDataset
 from .nlp_dataset import NLPDataset
-from .bert_dataset import BertClassificationDataset, BertTaggingDataset
+from .bert_dataset import (
+    BertClassificationDataset,
+    BertTaggingDataset,
+    BertSimilarityDataset,
+)
 
 
 __all__ = [
@@ -11,4 +16,6 @@ __all__ = [
     "TaggingDataset",
     "BertClassificationDataset",
     "BertTaggingDataset",
+    "SimilarityDataset",
+    "BertSimilarityDataset",
 ]
