@@ -3,10 +3,13 @@ from .precision_recall_f1 import (
     RecallWithLogits,
     FBetaScoreWithLogits,
 )
+from .accuracy import BinaryAccuracyWithLogits, AccuracyWithLogits
 from .utils import logits2scores, logits2classes, scores2classes
 
 
 __all__ = [
+    "BinaryAccuracyWithLogits",
+    "AccuracyWithLogits",
     "PrecisionWithLogits",
     "RecallWithLogits",
     "FBetaScoreWithLogits",
